@@ -409,9 +409,9 @@ create_projection_plots <- function(data,
 
   # Create combined plot
   voronoi_plot_plus_ellipse <- voronoi_plot +
-    ggplot2::stat_ellipse(
+    stat_ellipse(
       data = plot_dataframe,
-      ggplot2::aes(x = x, y = y, color = group_color, fill = group_primary),
+      aes(x = x, y = y, color = group_color, fill = group_primary),
       geom = "polygon",
       alpha = ellipse_alpha,
       show.legend = FALSE
